---
title: "Test Report"
author: "Mattias"
date: "March 22, 2017"
output:
  html_document:
    highlight: null
    number_sections: no
    theme: null
    mathjax: null
---


## R Markdown

This is an R Markdown document.

Test include from snakemake `r snakemake@params[["test"]]`.
